@@ -161,7 +161,7 @@ class Audio(typepad.Audio, Asset):
 
     @property
     def link(self):
-        return self.source.permalink_url
+        return self.audio_link.url
 
     def save(self, file=None, group=None):
         # Warning - this only handles create, not update
@@ -169,8 +169,9 @@ class Audio(typepad.Audio, Asset):
         assert group, "group parameter is unassigned"
         assert file, "file parameter is unassigned"
         self.groups = [ group.id ]
-        typepad.api.browser_upload.upload(
+        resp, cont = typepad.api.browser_upload.upload(
             self, file, post_type=self.type_id, redirect_to='http://example.com/none')
+        typepad.api.browser_upload.raise_error_for_response(resp, self)
 
 
 class Video(typepad.Video, Asset):
@@ -191,7 +192,7 @@ class Video(typepad.Video, Asset):
         return self.video_link.permalink_url
 
     def set_link(self, value):
-        self.video_link.permalink_url = value
+        self.video_link = typepad.VideoLink(permalink_url=value)
 
     link = property(get_link, set_link)
 
@@ -226,8 +227,9 @@ class Photo(typepad.Photo, Asset):
         assert group, "group parameter is unassigned"
         assert file, "file parameter is unassigned"
         self.groups = [ group.id ]
-        typepad.api.browser_upload.upload(
+        resp, cont = typepad.api.browser_upload.upload(
             self, file, post_type=self.type_id, redirect_to='http://example.com/none')
+        typepad.api.browser_upload.raise_error_for_response(resp, self)
 
 
 class LinkAsset(typepad.LinkAsset, Asset):
